@@ -18,6 +18,7 @@ class TestExecutor:
         self.available_plans = {}
 
     def add_test_plan(self, task_set, workers=1):
+        logging.info(f"schedule {workers} worker(s) for test plan: {task_set}")
         for a in range(workers):
             self.workers.append(Worker(f"thread{a}", task_set, ansi_colors=self.ansi_colors, debug=self.debug))
         self.test_plans += 1
@@ -29,13 +30,14 @@ class TestExecutor:
         """
         stat = Statistics()
         with Pool(len(self.workers)) as p:
-            procs = [Process(target=self.start_process, args=[w, stat, shared_state]) for w in self.workers]
+            procs = [Process(name=f"Worker{w.id}", target=self.start_process, args=[w, stat, shared_state]) for w in self.workers]
             for p in procs: p.start()
             for p in procs: p.join()
             pids = [x.pid for x in procs]
             for pid in pids:
                 multiprocess.mark_process_dead(pid)
             self.done(stat)
+        logging.info(f"Executor workers in child processed were finished")
 
     def start_process(self, worker, stat, shared_state):
         shared_state.init_multiprocess()
@@ -44,6 +46,7 @@ class TestExecutor:
         id, name = worker.id, worker.name
         task_set = worker.task_set.__class__.__name__
         worker.set_title(f"{task_set} [pid {os.getpid():6d}<:{os.getppid()}]")
+        worker.set_process_name(f"{task_set}_{id}")
         worker.log("start process")
         worker.gc = ProcessStat()
         worker.execute()
