@@ -103,8 +103,6 @@ class Prometheus:
         self.influx = Influx(self.registry)
         self.args = []
 
-        self.ppp = ProcessStat()
-
     def filter(self, *args):
         self.args = args
 
@@ -125,6 +123,6 @@ class Prometheus:
             logging.exception("problem with temporary prometheus dir: ")
 
     def start_server_process(self):
-        self.prom_server = Process(target=run_server, args=())
+        self.prom_server = Process(name="PrometheusHttp", target=run_server, args=())
         self.prom_server.start()
 
