@@ -9,12 +9,13 @@ from asyncio.locks import BoundedSemaphore
 from random import randint
 
 from lemmings.task_set_run import TaskSetRun
-from lemmings.utils import _num, duration2sec, exception_with_line
+from lemmings.utils import _num, duration2sec, exception_with_line, Summary, timed_execution
 from lemmings.utils.colors import Color
 from lemmings.utils.const import DONE, FAIL
 
 program_start = time.time()
 
+task_delay_latency = Summary(f'task_delay', f'Delay in tasks scheduling', ["task", "process", "process_group"])
 
 class Worker:
     total = 0
@@ -47,13 +48,18 @@ class Worker:
     def set_statistics(self, stat):
         self.stat = stat
 
-    async def run_task(self, offset, task):
+    @timed_execution
+    async def task_delay(self, name, offset):
         begin = time.time()
         d = duration2sec(offset)
         await asyncio.sleep(d)
         delay = time.time() - begin - d
         if delay > 1: # difference more than 1 sec
-            logging.warning(f"running late task {task.title} [delay: {delay:.2f}], scheduled at {d:.2f} | {offset}")
+            logging.warning(f"running late task {name} [delay: {delay:.2f}], scheduled at {d:.2f} | {offset}")
+            task_delay_latency.labels(task=name, process=os.getpid(), process_group=os.getppid()).observe(delay)
+
+    async def run_task(self, offset, task):
+        await self.task_delay(task.title, offset)
 
         def print_stat(prefix, print=True, comment="", success=False, failed=False):
             succ = _num(self.stat.executed)
